# pidi plugins

`pidi` is a daemon that downloads album art for songs playing in `mpd`/`mopidy` and displays them in a little window.

These plugins add additional display output and client type support to `pidi`, allowing album art display on things like the ST7789 or ILI9341 SPI LCD.
